==> CntNumber-0.9.4.1.tar.gz: CntNumber-0.9.4.1/setup.py <==
from distutils.core import setup
with open("README.txt","r",encoding='utf8') as fh:
  long_description = fh.read()
print(long_description)
setup(
  name = 'CntNumber',         # How you named your package folder (MyLib)
  packages = ['CntNumber'],   # Chose the same as "name"
  version = '0.9.4.1',      # Start with a small number and increase it with every change you make
  license='afl-3.0',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'CM is good boy, DSA no.1',   # Give a short description about your library
  author = 'CM',                   # Type in your name
  author_email = 'cm.for.dev@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Cmccm123',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Cmccm123/CntNumber/archive/refs/tags/Chinese.numbers.tar.gz',    # I explain this later on
  keywords = ['Chinese numerals', 'translation'],   # Keywords that define your package best
  install_requires=[],
  long_description=long_description,
  long_description_content_type="text/x-rst",
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)

==> CntNumber-0.9.5.tar.gz: CntNumber-0.9.5/setup.py <==
from distutils.core import setup
with open("README.txt","r",encoding='utf8') as fh:
  long_description = fh.read()
print(long_description)
setup(
  name = 'CntNumber',         # How you named your package folder (MyLib)
  packages = ['CntNumber'],   # Chose the same as "name"
  version = '0.9.5',      # Start with a small number and increase it with every change you make
  license='afl-3.0',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'CM is good boy, DSA no.1',   # Give a short description about your library
  author = 'CM',                   # Type in your name
  author_email = 'cm.for.dev@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Cmccm123',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Cmccm123/CntNumber/archive/refs/tags/Chinese.numbers.tar.gz',    # I explain this later on
  keywords = ['Chinese numerals', 'translation'],   # Keywords that define your package best
  install_requires=[],
  long_description=long_description,
  long_description_content_type="text/x-rst",
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)
